@@ -5,7 +5,6 @@ from itertools import product
 from string import ascii_letters, digits, punctuation
 
 import hypothesis.strategies as st
-import numpy as np
 import pytest
 from hypothesis import assume, given, settings
 
@@ -164,6 +163,7 @@ def partial_ratio_short_needle(s1, s2):
 
 
 def cdist_scorer(queries, choices, scorer):
+    import numpy as np
     matrix = np.zeros((len(queries), len(choices)), dtype=np.uint8)
 
     for i, query in enumerate(queries):
@@ -174,6 +174,7 @@ def cdist_scorer(queries, choices, scorer):
 
 
 def cdist_distance(queries, choices, scorer):
+    import numpy as np
     matrix = np.zeros((len(queries), len(choices)), dtype=np.int32)
 
     for i, query in enumerate(queries):
@@ -209,7 +210,7 @@ def test_matching_blocks(s1, s2):
     """
     test correct matching block conversion
     """
-    ops = metrics_cpp.levenshtein_editops(s1, s2)
+    ops = Levenshtein.editops(s1, s2)
     assert ops.as_matching_blocks() == ops.as_opcodes().as_matching_blocks()
 
 
@@ -219,7 +220,7 @@ def test_levenshtein_editops(s1, s2):
     """
     test Levenshtein.editops with any sizes
     """
-    ops = metrics_cpp.levenshtein_editops(s1, s2)
+    ops = Levenshtein.editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -229,7 +230,7 @@ def test_levenshtein_editops_block(s1, s2):
     """
     test Levenshtein.editops for long strings
     """
-    ops = metrics_cpp.levenshtein_editops(s1, s2)
+    ops = Levenshtein.editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -239,7 +240,7 @@ def test_indel_editops(s1, s2):
     """
     test Indel.editops with any sizes
     """
-    ops = metrics_cpp.indel_editops(s1, s2)
+    ops = Indel.editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -249,7 +250,7 @@ def test_indel_editops_block(s1, s2):
     """
     test Indel.editops for long strings
     """
-    ops = metrics_cpp.indel_editops(s1, s2)
+    ops = Indel.editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -259,7 +260,7 @@ def test_levenshtein_opcodes(s1, s2):
     """
     test Levenshtein.opcodes with any sizes
     """
-    ops = metrics_cpp.levenshtein_opcodes(s1, s2)
+    ops = Levenshtein.opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -269,7 +270,7 @@ def test_levenshtein_opcodes_block(s1, s2):
     """
     test Levenshtein.opcodes for long strings
     """
-    ops = metrics_cpp.levenshtein_opcodes(s1, s2)
+    ops = Levenshtein.opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -279,7 +280,7 @@ def test_indel_opcodes(s1, s2):
     """
     test Indel.opcodes with any sizes
     """
-    ops = metrics_cpp.indel_opcodes(s1, s2)
+    ops = Indel.opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -289,7 +290,7 @@ def test_indel_opcodes_block(s1, s2):
     """
     test Indel.opcodes for long strings
     """
-    ops = metrics_cpp.indel_opcodes(s1, s2)
+    ops = Indel.opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
